@@ -51,8 +51,11 @@ class API(object):
         if not https:
             raise Exception("The DomainTools API endpoints no longer support http traffic. Please make sure https=True.")
         if proxy_url:
-            self.extra_request_params['proxies'] = {'http': proxy_url, 'https': proxy_url}
-            self.extra_aiohttp_params['proxy'] = proxy_url
+            if isinstance(proxy_url, str):
+                self.extra_request_params['proxies'] = {'http': proxy_url, 'https': proxy_url}
+                self.extra_aiohttp_params['proxy'] = proxy_url
+            else:
+                raise Exception("Proxy URL must be a string. For example: '127.0.0.1:8888'")
 
     def _rate_limit(self):
         """Pulls in and enforces the latest rate limits for the specified user"""
@@ -110,7 +113,7 @@ class API(object):
 
         api_calls = tuple((api_call for api_call in dir(API) if not api_call.startswith('_') and
                            callable(getattr(API, api_call, None))))
-        return [snakecase(p["id"]) for p in self.account_information()["products"] if snakecase(p["id"]) in api_calls]
+        return sorted([snakecase(p["id"]) for p in self.account_information()["products"] if snakecase(p["id"]) in api_calls])
 
     def brand_monitor(self, query, exclude=None, domain_status=None, days_back=None, **kwargs):
         """Pass in one or more terms as a list or separated by the pipe character ( | )"""
